#!/bin/bash

configscripts=/usr/share/webapps/spectre/configscripts
tomcatconf=/usr/share/tomcatSpectre/conf
iptables_prd=${configscripts}/iptables_prd
iptables_dbg=${configscripts}/iptables_addition
pghbaconf_prd=${configscripts}/pg_hba.conf.prd
pghbaconf_dbg=${configscripts}/pg_hba.conf.debug
pgsqlconf_prd=${configscripts}/postgresql.conf.prd
pgsqlconf_dbg=${configscripts}/postgresql.conf.debug
tmctsrvr_prd=${configscripts}/server.xml.prd
tmctsrvr_dbg=${configscripts}/server.xml.debug
sshconf_prd=/etc/ssh/sshd_config
postgresql_path=/var/lib/pgsql/9.1/data
postgresql=postgresql-9.1

flag=$1

# Default behaviour on no incoming parameters
if [ -z $flag ]; then flag=on ; fi

# Case insensitive parameter check
case $flag in
    [oO][fF][fF]) flag=off;;
    [oO][nN]) flag=on;;
    *) echo "invalid input parameter"; exit;;
esac

echo "turning debug mode $flag"

if [ "$flag" == "on" ]; then

  #====== Stop the services =====#
  sudo /sbin/service tomcatSpectre stop
  sudo /sbin/service ${postgresql} stop

  #====== Disable firewall =====#
  sudo /usr/sbin/lokkit -q --disabled
  
  #====== Set iptables entry =====#
  if [ ! -f "${iptables_prd}" ]; then
      sudo cat /etc/sysconfig/iptables >> ${iptables_prd}
  fi
  sudo cat ${iptables_dbg} >> /etc/sysconfig/iptables
  sudo /sbin/service iptables restart

  #====== Enable root login =====#
  if [ -f /etc/passwd ]; then 
      sed -i "s/root:x:0:0:root:\/root:\/sbin\/nologin/root:x:0:0:root:\/root:\/bin\/bash/g;" /etc/passwd
  fi

  #====== Open up sshd =====#
  sudo /sbin/service sshd start
  sudo /sbin/chkconfig sshd on

  #====== Open up PostgreSQL =====#
  if [ ! -f "${pghbsconf_prd}" ]; then
      sudo cp -f ${postgresql_path}/pg_hba.conf ${pghbaconf_prd}
  fi
  if [ ! -f "${pgsqlconf_prd}" ]; then
      sudo cp -f ${postgresql_path}/postgresql.conf ${pgsqlconf_prd}
  fi
  sudo cp -f ${pghbaconf_dbg} ${postgresql_path}/pg_hba.conf
  sudo cp -f ${pgsqlconf_dbg} ${postgresql_path}/postgresql.conf
  sudo /sbin/service ${postgresql} start
 
  #====== Open up web service =====#
  if [ ! -f "${tmctsrvr_prd}" ]; then
      sudo cp -f ${tomcatconf}/server.xml ${tmctsrvr_prd}
  fi
  sudo cp -f ${tmctsrvr_dbg} ${tomcatconf}/server.xml
  sudo /sbin/service tomcatSpectre start

elif [ "$flag" == "off" ]; then

  #====== Stop the services =====#
  sudo /sbin/service tomcatSpectre stop
  sudo /sbin/service ${postgresql} stop

  #====== Lock up PostgreSQL =====#
  sudo cp -f ${pgsqlconf_prd} ${postgresql_path}/postgresql.conf
  sudo cp -f ${pghbaconf_prd} ${postgresql_path}/pg_hba.conf
  sudo /sbin/service ${postgresql} start

  #====== Lock up web service =====#
  sudo cp -f ${tmctsrvr_prd} ${tomcatconf}/server.xml
  sudo /sbin/service tomcatSpectre start

  #====== Lock up sshd =====#
  sudo /sbin/service sshd stop
  sudo /sbin/chkconfig sshd off

  #====== Disable root login =====#
  if [ -f /etc/passwd ]; then 
      sed -i "s/root:x:0:0:root:\/root:\/bin\/bash/root:x:0:0:root:\/root:\/sbin\/nologin/g;" /etc/passwd
  fi

  #====== Reset iptables entry =====#
  sudo cat ${iptables_prd} >> /etc/sysconfig/iptables
  sudo /sbin/service iptables restart

  #====== Enable firewall =====#
  sudo /usr/sbin/lokkit -q --enabled

fi

