#!/usr/bin/env python
# Winston Fernandes
# 


from __future__ import print_function

import HTMLParser
import subprocess
import urllib2
import os, re
import zipfile
import xml.etree.ElementTree as ET
import sys



def get_files(folder_path):
	ret = []
	for path, subdirs, files in os.walk(folder_path):
		for name in files:
			ret.append(os.path.join(path, name))
	return ret


def extract_files(files, dir_name):
	os.chdir(dir_name)
	extracted_files = []
	for file in files:
		if zipfile.is_zipfile(file):
			zip_ref = zipfile.ZipFile(file)
			temp_file = file[:-4]
			(head1, tail1) = os.path.split(file)
			(head2, tail2) = os.path.split(temp_file)
			zip_map[tail2] = tail1
			temp_file = temp_file + "/"
			zip_ref.extractall(temp_file)
			extracted_files.append(temp_file)
			zip_ref.close()
	return extracted_files


def get_metadata_files(files):
        extracted_metadata_files=[]
        for file in files:
                extracted_metadata_files.append(file + "metadata.zip")
        return extracted_metadata_files


def indent(elem, level=0):
    i = "\n" + level*"  "
    j = "\n" + (level-1)*"  "
    if len(elem):
        if not elem.text or not elem.text.strip():
            elem.text = i + "  "
        if not elem.tail or not elem.tail.strip():
            elem.tail = i
        for subelem in elem:
            indent(subelem, level+1)
        if not elem.tail or not elem.tail.strip():
            elem.tail = j
    else:
        if level and (not elem.tail or not elem.tail.strip()):
            elem.tail = j
    return elem        

        
def get_zip_information(file):
        tree = ET.parse(file)
        root = tree.getroot()
        file = file.replace("/metadata/vmware.xml", "")
        vibList = []
        (head, tail) = os.path.split(file)
        for bulletin in tree.findall('bulletin'):
                platforms = bulletin.find('platforms')  
                for viblist in bulletin.findall('vibList'):
                        for vib in viblist.findall('vib'):
                                tempVib = {}
                                name = vib.find('name')
                                tempVib['name'] = name
                                version = vib.find('version')
                                tempVib['version'] = version
                                reboot = vib.find('postInstall/rebootRequired')
                                tempVib['reboot'] = reboot
                                vendor = vib.find('vendor')
                                tempVib['vendor'] = vendor
                                tempVib['platform'] = platforms
                                vibList.append(tempVib)
        package[tail] =  vibList                  



package = {}
zip_map = {}
path=sys.argv[1]
print(path)
zip_files = get_files(path)
files = extract_files(zip_files,path)
metadata_zips = get_metadata_files(files)
metadata_files = extract_files(metadata_zips,path)
for meta_file in metadata_files:
        get_zip_information(meta_file + "vmware.xml")
catalog = ET.Element('catalog')
for package, vibs in package.items():
	packageElement = ET.SubElement(catalog, 'component')
	packageName = ET.SubElement(packageElement, 'name')
	packageName.text = package
	packagePath = ET.SubElement(packageElement, 'path')
	packagePath.text = zip_map[package]
	vibListElement = ET.SubElement(packageElement, 'vibList')
	for vib in vibs:
		print(vib)
		vibElement = ET.SubElement(vibListElement, 'vib')
		vibElement.insert(0,vib['name'])
		vibElement.insert(1,vib['version'])
		vibElement.insert(2,vib['vendor'])
		vibElement.insert(3,vib['reboot'])
		vibElement.insert(4,vib['platform'])
indent(catalog)
doc = ET.ElementTree(catalog)
doc.write(open('catalog.xml', 'wb'))
        
        
        

    
    


